Settings – Language Switch Mockup

IDEA-020 · CR-Switch Language in Settings · Mockup v1

# Settings

Configure your X-IPE application

Language English
Interface Language
Controls copilot instructions and prompt display language for the active project.
Switching language will regenerate copilot instructions. Custom edits outside X-IPE markers are preserved.
Project Folders

Name | Path | Actions
--- | --- | ---
X-IPE Active | /Users/yzhang/ML/2026/agent/X-IPE |
Demo App | /Users/yzhang/projects/demo-app |

Project Configuration Detected
Config file: `.x-ipe.yaml`

Version | `1`
Project Root | `.`
CLI | `copilot`
Language | `en`

Back to Document Viewer
Switch Language?
This will update your project's copilot instructions.
From English To 中文
Project X-IPE
Copilot instructions (`.github/copilot-instructions.md`) will be regenerated. Custom edits outside X-IPE sections are preserved.
Language switched to 中文
Already using English